@@ -17,11 +17,11 @@ Config::Abstraction - Configuration Abstraction Layer
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =cut
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 =head1 SYNOPSIS
 
@@ -504,7 +504,7 @@ sub _load_config
 	$prefix =~ s/_$//;
 	$prefix =~ s/::$//;
 	for my $key (keys %ENV) {
-		next unless $key =~ /^$self->{env_prefix}(.*)$/;
+		next unless $key =~ /^$self->{env_prefix}(.*)$/i;
 		my $path = lc $1;
 		if($path =~ /__/) {
 			my @parts = split /__/, $path;
@@ -669,6 +669,9 @@ sub AUTOLOAD
 
 It should be possible to escape the separator character either with backslashes or quotes.
 
+Due to the case-insensitive nature of environment variables on Windows,
+it may be challenging to override values using environment variables on that platorm.
+
 =head1 SUPPORT
 
 This module is provided as-is without any warranty.
